![PyPI - Downloads](https://img.shields.io/pypi/dm/fancy-abak)
![PyPI](https://img.shields.io/pypi/v/fancy-abak?style=flat)

# fancy-abak

CLI tool to use ABAK

## Requirements

* (Tested and built using) Python >3.6

## Installation

Package is available in PyPi:

`pip install fancy-abak`

## Roadmap

1. Batch duplicate
2. Parallel apply
